@@ -77,6 +77,11 @@ sub list_action {
     return $self->render( template => 'list.tt', items => [ $rs->search ] );
 }
 
+sub after_POST {
+    my( $self, @ids ) = @_;
+    return $self->self_url . join( '/', @ids ) . '/view';
+}
+
 sub create_action {
     my ( $self ) = @_;
     my $req = $self->req;
@@ -92,7 +97,7 @@ sub create_action {
     if( $req->method eq 'POST' && $form->process() ){
         my $record = $form->item;
         my $res = $req->new_response();
-        $res->redirect( $self->self_url . $record->id . '/view' );
+        $res->redirect( $self->after_POST( $record->id ) );
         return $res;
     }
     $form->field( 'submit' )->value( 'Create' );
@@ -129,7 +134,7 @@ sub edit {
     );
     if( $req->method eq 'POST' && $form->process() ){
         my $res = $req->new_response();
-        $res->redirect( $self->self_url . $record->id . '/view' );
+        $res->redirect( $self->after_POST( $record->id ) );
         return $res;
     }
     $form->field( 'submit' )->value( 'Update' );
@@ -148,7 +153,7 @@ WebNano::Controller::CRUD - A base controller implementing CRUD operations (EXPE
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -184,6 +189,8 @@ This is experimental Template Tookit and DBIx::Class based CRUD controller for L
 
 =head2 columns
 
+=head2 after_POST
+
 =head1 AUTHOR
 
 Zbigniew Lukasiak <zby@cpan.org>
